pub fn eval_phase_two(
tx: &MintedTx<'_>,
utxos: &[ResolvedInput],
cost_mdls: Option<&CostModels>,
initial_budget: Option<&ExBudget>,
slot_config: &SlotConfig,
run_phase_one: bool,
with_redeemer: fn(&Redeemer),
) -> Result<Vec<(Redeemer, EvalResult)>, Error>Expand description
Evaluate the scripts in a transaction using the UPLC Cek Machine. This function collects redeemers with ExUnits calculated from the evaluation. You may optionally run a subset of phase one checks on redeemers and scripts.